@@ -50,7 +50,7 @@ use Data::Dumper;
 
 use vars qw($VERSION);
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 =head1 METHODS
 
@@ -159,6 +159,20 @@ sub stow {
     $id;
 } #stow
 
+=head2 has_id( id )
+
+Returns true if an object with this db exists in the record store.
+
+=cut
+sub has_id {
+    my( $self, $id ) = @_;
+    my $ec = $self->entry_count;
+    return 0 if $ec < $id;
+
+    my( $store_id, $id_in_store ) = @{ $self->{OBJ_INDEX}->get_record( $id ) };
+    $store_id > 0;
+}
+
 =head2 fetch( id )
 
 Returns the record associated with the ID. If the ID has no 
@@ -189,7 +203,7 @@ sub recycle {
     
     my $store = $self->_get_store( $store_id );
     $store->recycle( $id_in_store );
-    $self->{OBJ_INDEX}->recycle( $id_in_store );
+    $self->{OBJ_INDEX}->recycle( $id );
 
 } #recycle
 
@@ -211,13 +225,13 @@ sub _best_store_for_size {
         }
     } #each store
     
-    if( $best_store ) {
+    if( $best_store && $best_size < $record_size * 2) {
         return $best_idx, $best_store;
-    } 
+    }
 
     # Have to create a new store. 
-    # Make one that is thrice the size of the record
-    my $store_size = 3 * $record_size;
+    # Make one that is the  size of the record
+    my $store_size = $record_size;
     my $store_id = $self->{STORE_IDX}->next_id;
 
     # first, make an entry in the store index, giving it that size, then
@@ -463,7 +477,6 @@ sub get_record {
 # how about an ensure_entry_count right here?
     # also a has_record
     if( $idx < 1 ) {
-        use Carp 'longmess'; print STDERR Data::Dumper->Dump([longmess]);
         die "get record must be a positive integer";
     }
    sysseek $fh, $self->{RECORD_SIZE} * ($idx-1), SEEK_SET or die "Could not seek ($self->{RECORD_SIZE} * ($idx-1)) : $@ $!";
@@ -472,6 +485,16 @@ sub get_record {
     [unpack( $self->{TMPL}, $data )];
 } #get_record
 
+=head2 has_id( id )
+
+Returns true if an object with this db exists in the record store.
+
+=cut
+sub has_id {
+    my( $self, $id ) = @_;
+    $self->{OBJ_INDEX}->has_id( $id );
+}
+
 =head2 next_id
 
 adds an empty record and returns its id, starting with 1
